@@ -10,6 +10,7 @@ import os
 import requests
 
 from .decorators import requires_api_key, get_api_key
+from .. import __version__ as client_version
 
 
 class APIClient(object):
@@ -26,7 +27,7 @@ class APIClient(object):
 		v : str
 			The API stage to use.
 		"""
-		return 'v1'
+		return 'v2'
 
 	@staticmethod
 	def url(path):
@@ -45,7 +46,7 @@ class APIClient(object):
 		"""
 		path = path.strip('/')
 
-		return 'https://api.kxysolutions.com/%s/' % APIClient.stage() + path
+		return 'https://api.kxy.ai/%s/' % APIClient.stage() + path
 
 
 	@staticmethod
@@ -76,6 +77,9 @@ class APIClient(object):
 			200: 
 				The request was successful and the API returned some data accessible through
 				`response.json()`.
+			402: 
+				The request failed because your account does not have a valid payment method.
+				Check `response.json()['reason']` for more information.
 			403: 
 				The request failed because some parameter are either invalid or missing.
 				Check `response.json()['reason']` for more information.
@@ -86,6 +90,8 @@ class APIClient(object):
 		"""
 		url = APIClient.url(path)
 		api_key = get_api_key()
+		if 'client_version' not in params:
+			params['client_version'] = client_version
 		response = requests.get(url, params=params, headers={'x-api-key': api_key, \
 			'content-type': 'application/json'})
 
@@ -123,6 +129,9 @@ class APIClient(object):
 			200: 
 				The request was successful and the API returned some data accessible through
 				`response.json()`.
+			402: 
+				The request failed because your account does not have a valid payment method.
+				Check `response.json()['reason']` for more information.
 			403: 
 				The request failed because some parameter are either invalid or missing.
 				Check `response.json()['reason']` for more information.
@@ -133,6 +142,8 @@ class APIClient(object):
 		"""
 		url = APIClient.url(path)
 		api_key = get_api_key()
+		if 'client_version' not in params:
+			params['client_version'] = client_version
 		response = requests.post(url, json=params, headers={'x-api-key': api_key, \
 			'content-type': 'application/json'})
 
@@ -173,6 +184,9 @@ class APIClient(object):
 			200: 
 				The request was successful and the API returned some data accessible through
 				`response.json()`.
+			402: 
+				The request failed because your account does not have a valid payment method.
+				Check `response.json()['reason']` for more information.
 			403: 
 				The request failed because some parameter are either invalid or missing.
 				Check `response.json()['reason']` for more information.
